#
# spec file for package python-jupyter-server-terminals
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%define skip_python39 1
%else
%define psuffix %{nil}
%bcond_with test
%endif

%define distversion 0.5.3
Name:           python-jupyter-server-terminals%{psuffix}
Version:        0.5.3
Release:        1.2
Summary:        A Jupyter Server Extension Providing Terminals
License:        BSD-3-Clause
URL:            https://github.com/jupyter-server/jupyter_server_terminals
Source:         https://files.pythonhosted.org/packages/source/j/jupyter_server_terminals/jupyter_server_terminals-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  jupyter-rpm-macros
BuildRequires:  python-rpm-macros
Requires:       jupyter-server-terminals = %{version}
Requires:       python-terminado >= 0.8.3
Provides:       python-jupyter_server_terminals = %{version}-%{release}
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module jupyter-server >= 2}
BuildRequires:  %{python_module jupyter-server-terminals = %{version}}
BuildRequires:  %{python_module pytest >= 7.0}
BuildRequires:  %{python_module pytest-jupyter-server >= 0.5.3}
BuildRequires:  %{python_module pytest-timeout}
%endif
%python_subpackages

%description
A Jupyter Server Extension Providing Terminals.

%package -n jupyter-server-terminals
Summary:        Jupyter Server Extension registration for python*-jupyter-server-terminals
Requires:       python3dist(jupyter-server-terminals) = %{distversion}

%description -n jupyter-server-terminals
A Jupyter Server Extension Providing Terminals.
This package provides the jupyter server registration

%prep
%setup -q -n jupyter_server_terminals-%{version}
sed -i 's/--color=yes//' pyproject.toml

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%jupyter_move_config
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.md CHANGELOG.md
%{python_sitelib}/jupyter_server_terminals
%{python_sitelib}/jupyter_server_terminals-%{version}.dist-info

%files -n jupyter-server-terminals
%license LICENSE
%_jupyter_config %_jupyter_server_confdir/jupyter_server_terminals.json
%endif

%changelog
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.5.3
  * Maintenance and upkeep improvements
* Thu Mar  7 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.5.2
  * Fix usage of await #106 (@blink1073)
  * Set terminals_available to False when not enabled #105
    (@Wh1isper)
- Skip testing on python39
* Sun Jan 21 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.5.1
  * fix: support OPTIONS method for CORS #102 (@zhanba)
* Sat Dec 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.5.0
  * Fix respecting serverapp.terminals_enabled #91 (@danielzgtg)
  * code maintenance
* Wed Nov  8 2023 Ben Greiner <code@bnavigator.de>
- Any python flavor is okay
* Wed Nov  8 2023 Matej Cepl <mcepl@suse.com>
- Fix a bad Requires: with %%{python_module construct.
* Sun Jan 22 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.4.4
  * Add typing file #74 (@blink1073)
  * Add spelling and docstring enforcement #72 (@blink1073)
* Mon Dec 26 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for v0.4.3
- Required by jupyter-server 2
